@@ -69,7 +69,7 @@ class DownloadAlbumMixin:
         paths = []
         for url in urls:
             file_name = urlparse(url).path.rsplit("/", 1)[1]
-            if file_name.endswith(".jpg"):
+            if file_name.endswith((".jpg", ".jpeg")):
                 paths.append(self.photo_download_by_url(url, file_name, folder))
             elif file_name.endswith(".mp4"):
                 paths.append(self.video_download_by_url(url, file_name, folder))
@@ -120,7 +120,7 @@ class UploadAlbumMixin:
         children = []
         for path in paths:
             path = Path(path)
-            if path.suffix == ".jpg":
+            if path.suffix in (".jpg", ".jpeg"):
                 upload_id, width, height = self.photo_rupload(path, to_album=True)
                 children.append(
                     {
